netapp_ontap.models.port_lag_member_ports API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.port_lag_member_ports`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class PortLagMemberPortsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the PortLagMemberPorts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the port_lag_member_ports.

  `name: str GET POST PATCH`

    The name field of the port_lag_member_ports.

    Example: e1b

  `node: BgpPeerGroupLocalPortNode GET POST PATCH`

    The node field of the port_lag_member_ports.

  `uuid: str GET POST PATCH`

    The uuid field of the port_lag_member_ports.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412